==> serveez-0.1.2.tar.gz: serveez-0.1.2/src/guile-api.h <==
/*
 * guile-api.h - compatibility and miscellaneous guile functionality
 *
 * Copyright (C) 2001 Stefan Jahn <stefan@lkcc.org>
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this package; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: guile-api.h,v 1.3 2001/11/27 14:21:33 ela Exp $
 *
 */

#ifndef __GUILE_API_H__
#define __GUILE_API_H__ 1

/* Some definitions for backward compatibility with Guile 1.3.4 */
#ifndef SCM_ASSERT_TYPE
#define SCM_ASSERT_TYPE(_cond, _arg, _pos, _subr, _msg) \
    SCM_ASSERT (_cond, _arg, _pos, _subr)
#define scm_wrong_type_arg_msg(_subr, _pos, _bad, _msg) \
    scm_wrong_type_arg (_subr, _pos, _bad)
#define scm_out_of_range_pos(_subr, _bad, _pos) \
    scm_out_of_range (_subr, _bad)
#endif /* not SCM_ASSERT_TYPE */

/* Compatibility definitions for various Guile versions.  These definitions
   are mainly due to the fact that the gh interface is deprecated in newer
   versions. */
#ifndef SCM_STRING_UCHARS
#define SCM_STRING_UCHARS(obj) ((unsigned char *) SCM_VELTS (obj))
#endif
#ifndef SCM_STRING_CHARS
#define SCM_STRING_CHARS(obj) ((char *) SCM_VELTS (obj))
#endif
#ifndef SCM_PROCEDUREP
#define SCM_PROCEDUREP(obj) SCM_NFALSEP (scm_procedure_p (obj))
#endif
#ifndef SCM_EXACTP
#define SCM_EXACTP(obj) SCM_NFALSEP (scm_exact_p (obj))
#endif
#ifndef SCM_PAIRP
#define SCM_PAIRP(obj) SCM_NFALSEP (scm_pair_p (obj))
#endif
#ifndef SCM_LISTP
#define SCM_LISTP(obj) SCM_NFALSEP (scm_list_p (obj))
#endif
#ifndef SCM_BOOLP
#define SCM_BOOLP(obj) SCM_NFALSEP (scm_boolean_p (obj))
#endif
#ifndef SCM_BOOL
#define SCM_BOOL(x) ((x) ? SCM_BOOL_T : SCM_BOOL_F)
#endif
#ifndef SCM_EQ_P
#define SCM_EQ_P(x, y) SCM_NFALSEP (scm_eq_p (x, y))
#endif
#ifndef SCM_CHARP
#define SCM_CHARP(obj) SCM_NFALSEP (scm_char_p (obj))
#endif
#ifndef SCM_CHAR
#define SCM_CHAR(x) SCM_ICHR (x)
#endif
#ifndef SCM_MAKE_CHAR
#define SCM_MAKE_CHAR(x) SCM_MAKICHR (x)
#endif
#ifndef scm_num2int
#define SCM_NUM2INT(pos, obj) gh_scm2int (obj)
#endif
#ifndef SCM_NUM2LONG
#define SCM_NUM2LONG(pos, obj) scm_num2long (obj, (char *) (pos), FUNC_NAME)
#endif
#ifndef SCM_NUM2ULONG
#define SCM_NUM2ULONG(pos, obj) scm_num2ulong (obj, (char *) (pos), FUNC_NAME)
#endif
#ifndef scm_int2num
#define scm_int2num(x) scm_long2num ((long) (x))
#endif
#ifndef scm_mem2string
#define scm_mem2string(str, len) gh_str2scm (str, len)
#endif
#ifndef scm_c_define
#define scm_c_define(name, val) gh_define (name, val)
#endif
#ifndef scm_c_free
#define scm_c_free(p) scm_must_free (p)
#endif
#ifndef scm_c_define_gsubr
#define scm_c_define_gsubr(name, req, opt, rst, fcn) \
    gh_new_procedure (name, fcn, req, opt, rst)
#endif
#ifndef scm_c_primitive_load
#define scm_c_primitive_load(file) \
    scm_primitive_load (scm_makfrom0str (file))
#endif
#ifndef scm_current_module_lookup_closure
#define guile_lookup(var, name) (var) = gh_lookup (name)
#else
#define guile_lookup(var, name) do {                                        \
    (var) = scm_sym2var (scm_str2symbol (name),                             \
	  	         scm_current_module_lookup_closure (), SCM_BOOL_F); \
    if (SCM_FALSEP (var)) (var) = SCM_UNDEFINED; } while (0)
#endif
#ifndef scm_gc_protect_object
#define scm_gc_protect_object(obj) scm_protect_object (obj)
#endif
#ifndef scm_gc_unprotect_object
#define scm_gc_unprotect_object(obj) scm_unprotect_object (obj)
#endif

/* Return an integer. If the given Guile cell @var{obj} is not such an 
   integer the routine return the default value @var{def}. */
#define guile_integer(pos, obj, def) \
    ((SCM_EXACTP (obj)) ? (SCM_NUM2INT (pos, obj)) : (def))

#endif /* not __GUILE_API_H__ */

==> serveez-0.1.3.tar.gz: serveez-0.1.3/src/guile-api.h <==
/*
 * guile-api.h - compatibility and miscellaneous guile functionality
 *
 * Copyright (C) 2001 Stefan Jahn <stefan@lkcc.org>
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this package; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * $Id: guile-api.h,v 1.7 2002/02/12 11:45:55 ela Exp $
 *
 */

#ifndef __GUILE_API_H__
#define __GUILE_API_H__ 1

/* Some definitions for backward compatibility with Guile 1.3.4 */
#ifndef SCM_ASSERT_TYPE
#define SCM_ASSERT_TYPE(_cond, _arg, _pos, _subr, _msg) \
    SCM_ASSERT (_cond, _arg, _pos, _subr)
#define scm_wrong_type_arg_msg(_subr, _pos, _bad, _msg) \
    scm_wrong_type_arg (_subr, _pos, _bad)
#define scm_out_of_range_pos(_subr, _bad, _pos) \
    scm_out_of_range (_subr, _bad)
#endif /* not SCM_ASSERT_TYPE */

/* Compatibility definitions for various Guile versions.  These definitions
   are mainly due to the fact that the gh interface is deprecated in newer
   versions. */
#ifndef SCM_STRING_UCHARS
#define SCM_STRING_UCHARS(obj) ((unsigned char *) SCM_VELTS (obj))
#endif
#ifndef SCM_STRING_CHARS
#define SCM_STRING_CHARS(obj) ((char *) SCM_VELTS (obj))
#endif
#ifndef SCM_PROCEDUREP
#define SCM_PROCEDUREP(obj) SCM_NFALSEP (scm_procedure_p (obj))
#endif
#ifndef SCM_EXACTP
#define SCM_EXACTP(obj) SCM_NFALSEP (scm_exact_p (obj))
#endif
#ifndef SCM_POSITIVEP
#define SCM_POSITIVEP(obj) SCM_NFALSEP (scm_positive_p (obj))
#endif
#ifndef SCM_NEGATIVEP
#define SCM_NEGATIVEP(obj) SCM_NFALSEP (scm_negative_p (obj))
#endif
#ifndef SCM_PAIRP
#define SCM_PAIRP(obj) SCM_NFALSEP (scm_pair_p (obj))
#endif
#ifndef SCM_LISTP
#define SCM_LISTP(obj) SCM_NFALSEP (scm_list_p (obj))
#endif
#ifndef SCM_BOOLP
#define SCM_BOOLP(obj) SCM_NFALSEP (scm_boolean_p (obj))
#endif
#ifndef SCM_BOOL
#define SCM_BOOL(x) ((x) ? SCM_BOOL_T : SCM_BOOL_F)
#endif
#ifndef SCM_EQ_P
#define SCM_EQ_P(x, y) SCM_NFALSEP (scm_eq_p (x, y))
#endif
#ifndef SCM_CHARP
#define SCM_CHARP(obj) SCM_NFALSEP (scm_char_p (obj))
#endif
#ifndef SCM_CHAR
#define SCM_CHAR(x) SCM_ICHR (x)
#endif
#ifndef SCM_MAKE_CHAR
#define SCM_MAKE_CHAR(x) SCM_MAKICHR (x)
#endif
#ifndef scm_num2int
#define SCM_NUM2INT(pos, obj) gh_scm2int (obj)
#endif
#ifndef SCM_NUM2LONG
#define SCM_NUM2LONG(pos, obj) scm_num2long (obj, (char *) (pos), FUNC_NAME)
#endif
#ifndef SCM_NUM2ULONG
#define SCM_NUM2ULONG(pos, obj) scm_num2ulong (obj, (char *) (pos), FUNC_NAME)
#endif
#ifndef scm_int2num
#define scm_int2num(x) scm_long2num ((long) (x))
#endif
#ifndef scm_mem2string
#define scm_mem2string(str, len) gh_str2scm (str, len)
#endif
#ifndef scm_c_define
#define scm_c_define(name, val) gh_define (name, val)
#endif
#ifndef scm_c_free
#define scm_c_free(p) scm_must_free (p)
#endif
#ifndef scm_c_define_gsubr
#define scm_c_define_gsubr(name, req, opt, rst, fcn) \
    gh_new_procedure (name, fcn, req, opt, rst)
#endif
#ifndef scm_c_primitive_load
#define scm_c_primitive_load(file) \
    scm_primitive_load (scm_makfrom0str (file))
#endif
#ifndef scm_current_module_lookup_closure
#define guile_lookup(var, name) (var) = gh_lookup (name)
#else
#define guile_lookup(var, name) do {                                        \
    (var) = scm_sym2var (scm_str2symbol (name),                             \
	  	         scm_current_module_lookup_closure (), SCM_BOOL_F); \
    if (SCM_FALSEP (var)) (var) = SCM_UNDEFINED; } while (0)
#endif
#ifndef scm_gc_protect_object
#define scm_gc_protect_object(obj) scm_protect_object (obj)
#endif
#ifndef scm_gc_unprotect_object
#define scm_gc_unprotect_object(obj) scm_unprotect_object (obj)
#endif
#ifndef scm_c_make_vector
#define scm_c_make_vector(k, fill) scm_make_vector (scm_int2num (k), fill)
#endif
#ifndef SCM_OUT_OF_RANGE
#define SCM_OUT_OF_RANGE(pos, arg) \
    scm_out_of_range_pos (FUNC_NAME, arg, SCM_MAKINUM (pos))
#endif

/* Return an integer. If the given Guile cell @var{obj} is not such an 
   integer the routine return the default value @var{def}. */
#define guile_integer(pos, obj, def) \
    ((SCM_EXACTP (obj)) ? (SCM_NUM2INT (pos, obj)) : (def))

/* The GUILE_CONCAT macros create a new concatenated symbol for the 
   compiler in a portable way. It is essential to use these macros like
   GUILE_CONCAT (a,b) and *not* like GUILE_CONCAT (a, b) or its variants. */
#if defined (__STDC__) || defined (__cplusplus)
# define GUILE_CONCAT2(a, b) a##b
# define GUILE_CONCAT3(a, b, c) a##b##c
#else
# define GUILE_CONCAT2(a, b) a/* */b
# define GUILE_CONCAT3(a, b, c) a/* */b/* */c
#endif

/* Compatibility macros for Guile 1.3 version. Also defines the macro
   HAVE_OLD_SMOBS which indicates a different smob implementation. */
#ifndef SCM_NEWSMOB
#define SCM_NEWSMOB(value, tag, data) do {                         \
    SCM_NEWCELL (value);                                           \
    SCM_SETCDR (value, data); SCM_SETCAR (value, tag); } while (0)
#endif
#ifndef SCM_RETURN_NEWSMOB
#define SCM_RETURN_NEWSMOB(tag, data) do { \
    SCM value;                             \
    SCM_NEWSMOB (value, tag, data);        \
    return value; } while (0)
#endif
#ifndef SCM_SMOB_DATA
#define SCM_SMOB_DATA(data) SCM_CDR (data)
#define gh_scm2chars(obj, lenp) guile_to_string (obj)
#define HAVE_OLD_SMOBS 1
#endif

#endif /* not __GUILE_API_H__ */
